#ifndef EAS_OPTIONS_CMAKE
#define EAS_OPTIONS_CMAKE

#define UNIFIED_DEBUG_MESSAGES
#define EAS_WT_SYNTH
#define EAS_FM_SYNTH
/* #undef EAS_HYBRID_SYNTH */
#define NUM_OUTPUT_CHANNELS 2
#define MAX_SYNTH_VOICES 64
#define _FILTER_ENABLED
#define DLS_SYNTHESIZER
#define _REVERB_ENABLED
#define _CHORUS_ENABLED
/* #undef _STATIC_MEMORY */
/* #undef _IMELODY_PARSER */
/* #undef _RTTTL_PARSER */
/* #undef _OTA_PARSER */
#define _XMF_PARSER
/* #undef JET_INTERFACE */
#define _RMID_PARSER

/* #undef _METRICS_ENABLED */
/* #undef MMAPI_SUPPORT */
/* #undef EXTERNAL_AUDIO */

/* #undef EAS_BIG_ENDIAN */
#define _16_BIT_SAMPLES
/* #undef _8_BIT_SAMPLES */
#define _SAMPLE_RATE_44100
/* #undef _SAMPLE_RATE_22050 */

#define _ZLIB_UNPACKER
#define _SF2_SUPPORT
#define _FLOAT_DCF
#define MP3_SUPPORT

#endif // EAS_OPTIONS_CMAKE
